@@ -7,7 +7,7 @@ from starlette.responses import JSONResponse
 from fastapi import FastAPI
 from starlette import status
 from kafka import KafkaConsumer
-from kafka.errors import KafkaError
+from kafka.errors import KafkaError, NoBrokersAvailable
 from google.cloud import bigquery
 from google.oauth2 import service_account
 from knada_kafka_consumer.bq import bigquery_writer
@@ -98,18 +98,23 @@ class ConsumerApp:
         return client
 
     def create_consumer(self) -> KafkaConsumer:
-
-        return KafkaConsumer(self._topic,
-                             bootstrap_servers=self._kafka_brokers,
-                             security_protocol='SASL_SSL',
-                             sasl_mechanism="PLAIN",
-                             sasl_plain_username=self._sasl_user,
-                             sasl_plain_password=self._sasl_password,
-                             ssl_cafile=self._kafka_ca_path,
-                             auto_offset_reset="earliest",
-                             group_id=self._kafka_group_id,
-                             enable_auto_commit=False,
-                             api_version_auto_timeout_ms=10000)
+        try:
+            consumer = KafkaConsumer(self._topic,
+                                     bootstrap_servers=self._kafka_brokers,
+                                     security_protocol='SASL_SSL',
+                                     sasl_mechanism="PLAIN",
+                                     sasl_plain_username=self._sasl_user,
+                                     sasl_plain_password=self._sasl_password,
+                                     ssl_cafile=self._kafka_ca_path,
+                                     auto_offset_reset="earliest",
+                                     group_id=self._kafka_group_id,
+                                     enable_auto_commit=False,
+                                     api_version_auto_timeout_ms=15000)
+        except NoBrokersAvailable:
+            self._is_alive = False
+        else:
+            self._is_alive = True
+            return consumer
 
     def format_message(self, message) -> dict:
         schema_res = kafka.get_schema_from_registry(schema_registry=self._schema_registry, message=message, schema_cache=self._schema_cache)
